==> cutetube_1.7.2.tar.gz: cutetube-1.7.2/cutetubeapp/src/base/abstractplaylistlistmodel.cpp <==
#include "abstractplaylistlistmodel.h"
#include "thumbnailcache.h"
#ifdef QML_USER_INTERFACE
#include <QDeclarativeEngine>
#endif

AbstractPlaylistListModel::AbstractPlaylistListModel(ThumbnailCache *cache, QObject *parent) :
    QAbstractListModel(parent),
    m_cache(cache)
{
    QHash<int, QByteArray> roles;
    roles[IdRole] = "id";
    roles[PlaylistIdRole] = "playlistId";
    roles[TitleRole] = "title";
    roles[ArtistRole] = "artist";
    roles[DateRole] = "date";
    roles[VideoCountRole] = "videoCount";
    roles[ThumbnailRole] = "thumbnail";
    roles[ThumbnailUrlRole] = "thumbnailUrl";
    roles[DescriptionRole] = "description";
    this->setRoleNames(roles);

#ifndef QML_USER_INTERFACE
    if (this->thumbnailCache()) {
        this->connect(this->thumbnailCache(), SIGNAL(thumbnailReady()), this, SLOT(onThumbnailReady()));
    }
#endif
}

AbstractPlaylistListModel::~AbstractPlaylistListModel() {
    m_list.clear();

    if (this->thumbnailCache()) {
        delete this->thumbnailCache();
    }
}

void AbstractPlaylistListModel::clear() {
    this->beginResetModel();
    m_list.clear();
    this->endResetModel();
}

void AbstractPlaylistListModel::setThumbnailCache(ThumbnailCache *cache) {
    m_cache = cache;
#ifndef QML_USER_INTERFACE
    if (this->thumbnailCache()) {
        this->connect(this->thumbnailCache(), SIGNAL(thumbnailReady()), this, SLOT(onThumbnailReady()));
    }
#endif
}

int AbstractPlaylistListModel::rowCount(const QModelIndex &parent) const {
    Q_UNUSED(parent)

    return m_list.size();
}

QVariant AbstractPlaylistListModel::data(const QModelIndex &index, int role) const {
    switch (role) {
    case IdRole:
        return m_list.at(index.row()).data()->id();
    case PlaylistIdRole:
        return m_list.at(index.row()).data()->playlistId();
    case TitleRole:
        return m_list.at(index.row()).data()->title();
    case ArtistRole:
        return m_list.at(index.row()).data()->artist();
    case DateRole:
        return m_list.at(index.row()).data()->date();
    case VideoCountRole:
        return m_list.at(index.row()).data()->videoCount();
#ifndef QML_USER_INTERFACE
    case ThumbnailRole:
        return !this->thumbnailCache() ? QVariant() : this->thumbnailCache()->thumbnail(m_list.at(index.row()).data()->thumbnailUrl(), QSize(120, 90));
#endif
    case ThumbnailUrlRole:
        return m_list.at(index.row()).data()->thumbnailUrl();
    case DescriptionRole:
        return m_list.at(index.row()).data()->description();
    default:
        return QVariant();
    }
}

QVariant AbstractPlaylistListModel::data(int row, const QByteArray &role) const {
    return this->data(this->index(row), this->roleNames().key(role));
}

QSharedPointer<PlaylistItem> AbstractPlaylistListModel::get(int row) const {
    if ((row >= 0) && (row < m_list.size())) {
        return QSharedPointer<PlaylistItem>(m_list.at(row));
    }

    return QSharedPointer<PlaylistItem>();
}

PlaylistItem* AbstractPlaylistListModel::getFromQML(int row) const {
#ifdef QML_USER_INTERFACE
    if ((row >= 0) && (row < m_list.size())) {
        PlaylistItem *playlist = new PlaylistItem(m_list.at(row).data());
        QDeclarativeEngine::setObjectOwnership(playlist, QDeclarativeEngine::JavaScriptOwnership);
        return playlist;
    }
#else
    Q_UNUSED(row)
#endif
    return 0;
}

void AbstractPlaylistListModel::insertPlaylist(int row, QSharedPointer<PlaylistItem> playlist) {
    this->beginInsertRows(QModelIndex(), row, row);
    m_list.insert(row, playlist);
    this->endInsertRows();
}

void AbstractPlaylistListModel::appendPlaylist(QSharedPointer<PlaylistItem> playlist) {
    this->beginInsertRows(QModelIndex(), this->rowCount(), this->rowCount());
    m_list.append(playlist);
    this->endInsertRows();
}

bool AbstractPlaylistListModel::removePlaylist(const QVariant &value, int role) {
    QModelIndexList indexes = this->match(this->index(0), role, value, 1, Qt::MatchExactly);

    if (indexes.isEmpty()) {
        return false;
    }

    return this->removeRow(indexes.first().row());
}

bool AbstractPlaylistListModel::removeRow(int row, const QModelIndex &parent)
{
    Q_UNUSED(parent)

    if ((row >= 0) && (row < m_list.size())) {
        this->beginRemoveRows(QModelIndex(), row, row);
        m_list.takeAt(row).clear();
        this->endRemoveRows();

        return true;
    }

    return false;
}

void AbstractPlaylistListModel::onThumbnailReady() {
#ifndef QML_USER_INTERFACE
    emit dataChanged(this->index(0), this->index(this->rowCount() - 1));
#endif
}

==> cutetube_1.7.7.tar.gz: cutetube-1.7.7/cutetubeapp/src/base/abstractplaylistlistmodel.cpp <==
#include "abstractplaylistlistmodel.h"
#ifndef QML_USER_INTERFACE
#include "thumbnailcache.h"
#endif

AbstractPlaylistListModel::AbstractPlaylistListModel(QObject *parent) :
    QAbstractListModel(parent)
  #ifndef QML_USER_INTERFACE
    ,m_cache(new ThumbnailCache)
  #endif
{
    QHash<int, QByteArray> roles;
    roles[IdRole] = "id";
    roles[PlaylistIdRole] = "playlistId";
    roles[TitleRole] = "title";
    roles[ArtistRole] = "artist";
    roles[DateRole] = "date";
    roles[VideoCountRole] = "videoCount";
#ifndef QML_USER_INTERFACE
    roles[ThumbnailRole] = "thumbnail";
#endif
    roles[ThumbnailUrlRole] = "thumbnailUrl";
    roles[DescriptionRole] = "description";
    this->setRoleNames(roles);
#ifndef QML_USER_INTERFACE
    this->connect(m_cache, SIGNAL(thumbnailReady()), this, SLOT(onThumbnailReady()));
#endif
}

AbstractPlaylistListModel::~AbstractPlaylistListModel() {
    m_list.clear();
#ifndef QML_USER_INTERFACE
    delete m_cache;
    m_cache = 0;
#endif
}

void AbstractPlaylistListModel::clear() {
    this->beginResetModel();
    m_list.clear();
    this->endResetModel();
}

int AbstractPlaylistListModel::rowCount(const QModelIndex &parent) const {
    Q_UNUSED(parent)

    return m_list.size();
}

QVariant AbstractPlaylistListModel::data(const QModelIndex &index, int role) const {
    switch (role) {
    case IdRole:
        return m_list.at(index.row()).data()->id();
    case PlaylistIdRole:
        return m_list.at(index.row()).data()->playlistId();
    case TitleRole:
        return m_list.at(index.row()).data()->title();
    case ArtistRole:
        return m_list.at(index.row()).data()->artist();
    case DateRole:
        return m_list.at(index.row()).data()->date();
    case VideoCountRole:
        return m_list.at(index.row()).data()->videoCount();
#ifndef QML_USER_INTERFACE
    case ThumbnailRole:
        return m_cache->thumbnail(m_list.at(index.row()).data()->thumbnailUrl(), QSize(120, 90));
#endif
    case ThumbnailUrlRole:
        return m_list.at(index.row()).data()->thumbnailUrl();
    case DescriptionRole:
        return m_list.at(index.row()).data()->description();
    default:
        return QVariant();
    }
}

QVariant AbstractPlaylistListModel::data(int row, const QByteArray &role) const {
    return this->data(this->index(row), this->roleNames().key(role));
}

QSharedPointer<PlaylistItem> AbstractPlaylistListModel::get(int row) const {
    if ((row >= 0) && (row < m_list.size())) {
        return QSharedPointer<PlaylistItem>(m_list.at(row));
    }

    return QSharedPointer<PlaylistItem>();
}

#ifdef QML_USER_INTERFACE
PlaylistItem* AbstractPlaylistListModel::getFromQML(int row) const {
    if ((row >= 0) && (row < m_list.size())) {
        return m_list.at(row).data();
    }

    return 0;
}
#endif

void AbstractPlaylistListModel::insertPlaylist(int row, QSharedPointer<PlaylistItem> playlist) {
    this->beginInsertRows(QModelIndex(), row, row);
    m_list.insert(row, playlist);
    this->endInsertRows();
}

void AbstractPlaylistListModel::appendPlaylist(QSharedPointer<PlaylistItem> playlist) {
    this->beginInsertRows(QModelIndex(), this->rowCount(), this->rowCount());
    m_list.append(playlist);
    this->endInsertRows();
}

bool AbstractPlaylistListModel::removePlaylist(const QVariant &value, int role) {
    QModelIndexList indexes = this->match(this->index(0), role, value, 1, Qt::MatchExactly);

    if (indexes.isEmpty()) {
        return false;
    }

    return this->removeRow(indexes.first().row());
}

bool AbstractPlaylistListModel::removeRow(int row, const QModelIndex &parent)
{
    Q_UNUSED(parent)

    if ((row >= 0) && (row < m_list.size())) {
        this->beginRemoveRows(QModelIndex(), row, row);
        m_list.takeAt(row).clear();
        this->endRemoveRows();

        return true;
    }

    return false;
}

#ifndef QML_USER_INTERFACE
void AbstractPlaylistListModel::onThumbnailReady() {
    emit dataChanged(this->index(0), this->index(this->rowCount() - 1));
}
#endif
